%------------------------------------------------------------------
% This file plots the phase-plane simulations presented in the CEP paper: 
%      1) (CEP Fig 3) Phase-plane comparison of polynomial short-period model
%       and 4-state polynomial models. 
%      2) (CEP Fig 6) Phase-plane simulation of polynomial short period
%      model with cubic pitch damping nonlineairty
%------------------------------------------------------------------

% Generate the GTM Models 
Gen_GTMAnalModel; 

%------------------------------------------------------------------
% (CEP Fig 3) Phase-plane comparison of polynomial short-period model
% and 4-state polynomial models. 
%------------------------------------------------------------------

Tf = 100;

% ---- Initial Condition gridding
x1 = linspace(-30*d2r,60*d2r,8);
y1 = linspace(-120*d2r,120*d2r,8);
X1Y1 = [min(x1)*ones(length(y1),1) y1'];
X2Y2 = [max(x1)*ones(length(y1),1) y1'];
X3Y3 = [x1' max(y1)*ones(length(x1),1)];
X4Y4 = [x1' min(y1)*ones(length(x1),1)];
x02 = [X1Y1; X2Y2; X3Y3; X4Y4;[-7.5+xtp(3)*r2d -30;-5+xtp(3)*r2d -30; -10+xtp(3)*r2d -30; ...
    7.5+xtp(3)*r2d -30; 12.5+xtp(3)*r2d -30; 10+xtp(3)*r2d 30; ...
    2.5+xtp(3)*r2d -30; 15+xtp(3)*r2d 30]*d2r ]';

for j1 = 1:length(x02)

    % this calls ode45 for polynomial object
    [xtraj2]=psim(f2nom,x(2:3),x02(:,j1),Tf);
    [xtraj4]=psim(f4nom,x,[0;x02(:,j1);0],Tf);

    isdiv = norm(xtraj4{2}(end,:)) >  10*norm(xtraj4{2}(1,:));
    isconv = ~isdiv;

    if isconv == 1
        figure(1)
        ph1 = plot((xtraj2{2}(:,1)+ xtp(2))*r2d, (xtraj2{2}(:,2)+ xtp(3))*r2d,'-k','LineWidth',3); 
        hold on ;
        ph2 = plot((xtraj4{2}(:,2)+ xtp(2))*r2d, (xtraj4{2}(:,3)+ xtp(3))*r2d,'--r','LineWidth',3); 
        hold on;
    end

    axis([min(x02(1,:)) max(x02(1,:)) min(x02(2,:)) max(x02(2,:))]*r2d);
    drawnow

end

grid on
xl = xlabel({'alpha (deg)'});
yl = ylabel({'q (deg/s)'});
set([xl,yl,gca],'FontSize',18);


%------------------------------------------------------------------
% (CEP Fig 6) Phase-plane simulation of polynomial short period
%      model with cubic pitch damping nonlineairty
%------------------------------------------------------------------

% ---- Initial Condition Gridding
x1 = linspace(-40*d2r,60*d2r,16);
y1 = linspace(-120*d2r,120*d2r,14);

X1Y1 = [min(x1)*ones(length(y1),1) y1'];
X2Y2 = [max(x1)*ones(length(y1),1) y1'];
X3Y3 = [x1' max(y1)*ones(length(x1),1)];
X4Y4 = [x1' min(y1)*ones(length(x1),1)];
x02 = [X1Y1; X2Y2; X3Y3; X4Y4;[24+xtp(3)*r2d 0; 26+xtp(3)*r2d 0; 28+xtp(3)*r2d 0; ...
    30+xtp(3)*r2d 0; 24+xtp(3)*r2d 30; 26+xtp(3)*r2d 60; 28+xtp(3)*r2d 60; ...
    30+xtp(3)*r2d 60]*d2r ]';

% Simulate 2-sate models
Tfinal = 250;

% Event params
event_params.nbig = 1e4;
event_params.nsmall = 0;
event_params.xbig = 1e4;
event_params.xsmall = 0;
event_params.funchandle =[];

figure(2)
for j1 = 1:length(x02)

    % this calls ode45 for polynomial object
    [xtraj]=psim(f2Cubic,x(2:3),x02(:,j1),Tf,event_params);
    isdiv = norm(xtraj{2}(end,:)) >  10*norm(xtraj{2}(1,:));
    isconv = ~isdiv; 

    if isconv == 1
          ph1 = plot((xtraj{2}(:,1)+ xtp(2))*r2d, (xtraj{2}(:,2)+ xtp(3))*r2d,'-b','LineWidth',2); hold on;
      else
          ph2 = plot((xtraj{2}(:,1)+ xtp(2))*r2d, (xtraj{2}(:,2)+ xtp(3))*r2d,'--r','LineWidth',3); hold on;
     end
     
     axis([min(x02(1,:)) max(x02(1,:)) min(x02(2,:)) max(x02(2,:))]*r2d);
     drawnow
     
end

grid on
xl = xlabel({'alpha (deg)'});
yl = ylabel({'q (deg/s)'});
set([xl,yl,gca],'FontSize',18);